@@ -11,6 +11,7 @@ from flux_led.protocol import (
 )
 
 from .aioprotocol import AIOLEDENETProtocol
+from .aioscanner import AIOBulbScanner
 from .base_device import PROTOCOL_PROBES, LEDENETDevice
 from .const import (
     COLOR_MODE_CCT,
@@ -85,9 +86,15 @@ class AIOWifiLedBulb(LEDENETDevice):
             raise RuntimeError("Could not determine number pixels")
 
     async def async_stop(self) -> None:
-        """Shutdown the connection"""
+        """Shutdown the connection."""
+        self._async_stop()
+
+    def _async_stop(self) -> None:
+        """Shutdown the connection and mark unavailable."""
+        self.set_unavailable()
         if self._aio_protocol:
             self._aio_protocol.close()
+        self._last_update_time = NEVER_TIME
 
     async def _async_send_state_query(self) -> None:
         assert self._protocol is not None
@@ -192,11 +199,13 @@ class AIOWifiLedBulb(LEDENETDevice):
                 # then no need to poll except for the interval
                 # to make sure the device is still responding
                 if self._protocol.state_push_updates:
+                    self._async_raise_if_offline()
                     return
             elif self._protocol.power_push_updates:
                 # If the device pushes power updates
                 # then no need to poll except for the interval
                 # to make sure the device is still responding
+                self._async_raise_if_offline()
                 return
         self._last_update_time = now
         if self._updates_without_response == MAX_UPDATES_WITHOUT_RESPONSE:
@@ -208,6 +217,11 @@ class AIOWifiLedBulb(LEDENETDevice):
         await self._async_send_state_query()
         self._updates_without_response += 1
 
+    def _async_raise_if_offline(self) -> None:
+        """Raise RuntimeError if the bulb is offline."""
+        if not self.available:
+            raise RuntimeError("Bulb not responding, too soon to retry")
+
     async def async_set_levels(
         self,
         r: Optional[int] = None,
@@ -345,6 +359,20 @@ class AIOWifiLedBulb(LEDENETDevice):
             await self.async_set_levels(w=brightness)
             return
 
+    async def async_enable_remote_access(
+        self, remote_access_host: str, remote_access_port: int
+    ) -> None:
+        """Enable remote access."""
+        await AIOBulbScanner().async_enable_remote_access(
+            self.ipaddr, remote_access_host, remote_access_port
+        )
+        self._async_stop()
+
+    async def async_disable_remote_access(self) -> None:
+        """Disable remote access."""
+        await AIOBulbScanner().async_disable_remote_access(self.ipaddr)
+        self._async_stop()
+
     async def _async_connect(self) -> None:
         """Create connection."""
         _, self._aio_protocol = await asyncio.wait_for(
