@@ -17,6 +17,7 @@ from .const import (  # imported for back compat, remove once Home Assistant no
     COLOR_MODES_RGB_CCT,
     COLOR_MODES_RGB_W,
     DEFAULT_MODE,
+    EFFECT_MUSIC,
     EFFECT_RANDOM,
     MAX_TEMP,
     MIN_TEMP,
@@ -28,6 +29,7 @@ from .const import (  # imported for back compat, remove once Home Assistant no
     MODE_WW,
     MODEL_NUMS_SWITCHS,
     PRESET_MUSIC_MODE,
+    PRESET_MUSIC_MODE_LEGACY,
     STATE_BLUE,
     STATE_CHANGE_LATENCY,
     STATE_COOL_WHITE,
@@ -55,8 +57,10 @@ from .pattern import (
 )
 from .protocol import (
     PROTOCOL_LEDENET_8BYTE,
+    PROTOCOL_LEDENET_8BYTE_AUTO_ON,
     PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS,
     PROTOCOL_LEDENET_9BYTE,
+    PROTOCOL_LEDENET_9BYTE_AUTO_ON,
     PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS,
     PROTOCOL_LEDENET_ADDRESSABLE_A1,
     PROTOCOL_LEDENET_ADDRESSABLE_A2,
@@ -66,8 +70,10 @@ from .protocol import (
     LEDENETOriginalRawState,
     LEDENETRawState,
     ProtocolLEDENET8Byte,
+    ProtocolLEDENET8ByteAutoOn,
     ProtocolLEDENET8ByteDimmableEffects,
     ProtocolLEDENET9Byte,
+    ProtocolLEDENET9ByteAutoOn,
     ProtocolLEDENET9ByteDimmableEffects,
     ProtocolLEDENETAddressableA1,
     ProtocolLEDENETAddressableA2,
@@ -88,8 +94,10 @@ PROTOCOL_PROBES: Tuple[Type[ProtocolLEDENET8Byte], Type[ProtocolLEDENETOriginal]
 
 PROTOCOL_TYPES = Union[
     ProtocolLEDENET8Byte,
+    ProtocolLEDENET8ByteAutoOn,
     ProtocolLEDENET8ByteDimmableEffects,
     ProtocolLEDENET9Byte,
+    ProtocolLEDENET9ByteAutoOn,
     ProtocolLEDENET9ByteDimmableEffects,
     ProtocolLEDENETAddressableA1,
     ProtocolLEDENETAddressableA2,
@@ -116,8 +124,10 @@ SPEED_ADJUST_WILL_TURN_ON = {
 PROTOCOL_NAME_TO_CLS = {
     PROTOCOL_LEDENET_ORIGINAL: ProtocolLEDENETOriginal,
     PROTOCOL_LEDENET_8BYTE: ProtocolLEDENET8Byte,
+    PROTOCOL_LEDENET_8BYTE_AUTO_ON: ProtocolLEDENET8ByteAutoOn,
     PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS: ProtocolLEDENET8ByteDimmableEffects,
     PROTOCOL_LEDENET_9BYTE: ProtocolLEDENET9Byte,
+    PROTOCOL_LEDENET_9BYTE_AUTO_ON: ProtocolLEDENET9ByteAutoOn,
     PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS: ProtocolLEDENET9ByteDimmableEffects,
     PROTOCOL_LEDENET_ADDRESSABLE_A3: ProtocolLEDENETAddressableA3,
     PROTOCOL_LEDENET_ADDRESSABLE_A2: ProtocolLEDENETAddressableA2,
@@ -128,6 +138,7 @@ PROTOCOL_NAME_TO_CLS = {
 
 PATTERN_CODE_TO_EFFECT = {
     PRESET_MUSIC_MODE: MODE_MUSIC,
+    PRESET_MUSIC_MODE_LEGACY: MODE_MUSIC,
     EFFECT_CUSTOM_CODE: EFFECT_CUSTOM,
 }
 
@@ -350,6 +361,8 @@ class LEDENETDevice:
             effects = ADDRESSABLE_EFFECT_ID_NAME.values()
         elif COLOR_MODES_RGB.intersection(self.color_modes):
             effects = EFFECT_LIST_DIMMABLE if self.dimmable_effects else EFFECT_LIST
+        if self.microphone:
+            return [*effects, EFFECT_RANDOM, EFFECT_MUSIC]
         return [*effects, EFFECT_RANDOM]
 
     @property
@@ -439,7 +452,7 @@ class LEDENETDevice:
             return MODE_COLOR
         elif pattern_code == EFFECT_CUSTOM_CODE:
             return MODE_CUSTOM
-        elif pattern_code == PRESET_MUSIC_MODE:
+        elif pattern_code in (PRESET_MUSIC_MODE, PRESET_MUSIC_MODE_LEGACY):
             return MODE_MUSIC
         elif PresetPattern.valid(pattern_code):
             return MODE_PRESET
@@ -593,10 +606,7 @@ class LEDENETDevice:
 
         if mode in STATIC_MODES:
             if color_mode in COLOR_MODES_RGB:
-                red = rx.red
-                green = rx.green
-                blue = rx.blue
-                mode_str = f"Color: {(red, green, blue)}"
+                mode_str = f"Color: {(rx.red, rx.green, rx.blue)}"
                 # Should add ability to get CCT from rgbwcapable*
                 if self.rgbwcapable:
                     mode_str += f" White: {rx.warm_white}"
@@ -610,8 +620,7 @@ class LEDENETDevice:
                     cct_value[0], round(cct_value[1] * 100 / 255)
                 )
         elif mode == MODE_PRESET:
-            pat = self.effect
-            mode_str = f"Pattern: {pat} (Speed {self.speed}%)"
+            mode_str = f"Pattern: {self.effect} (Speed {self.speed}%)"
         elif mode == MODE_CUSTOM:
             mode_str = f"Custom pattern (Speed {self.speed}%)"
         elif BuiltInTimer.valid(rx.preset_pattern):
