@@ -2,13 +2,14 @@
 
 from abc import abstractmethod
 import logging
-from typing import List, NamedTuple, Tuple, Union
+from typing import List, NamedTuple, Optional, Tuple, Union
 
 from .const import (
     TRANSITION_GRADUAL,
     TRANSITION_JUMP,
     TRANSITION_STROBE,
     LevelWriteMode,
+    MultiColorEffects,
 )
 from .utils import utils, white_levels_to_scaled_color_temp
 
@@ -17,8 +18,10 @@ _LOGGER = logging.getLogger(__name__)
 # Protocol names
 PROTOCOL_LEDENET_ORIGINAL = "LEDENET_ORIGINAL"
 PROTOCOL_LEDENET_9BYTE = "LEDENET"
+PROTOCOL_LEDENET_9BYTE_AUTO_ON = "LEDENET_AUTO_ON"
 PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS = "LEDENET_DIMMABLE_EFFECTS"
 PROTOCOL_LEDENET_8BYTE = "LEDENET_8BYTE"  # Previously was called None
+PROTOCOL_LEDENET_8BYTE_AUTO_ON = "LEDENET_8BYTES_AUTO_ON"
 PROTOCOL_LEDENET_8BYTE_DIMMABLE_EFFECTS = "LEDENET_8BYTE_DIMMABLE_EFFECTS"
 PROTOCOL_LEDENET_ADDRESSABLE_A1 = "LEDENET_ADDRESSABLE_A1"
 PROTOCOL_LEDENET_ADDRESSABLE_A2 = "LEDENET_ADDRESSABLE_A2"
@@ -35,6 +38,20 @@ LEDENET_ORIGINAL_STATE_RESPONSE_LEN = 11
 LEDENET_STATE_RESPONSE_LEN = 14
 LEDENET_POWER_RESPONSE_LEN = 4
 LEDENET_ADDRESSABLE_STATE_RESPONSE_LEN = 25
+LEDENET_IC_STATE_RESPONSE_LEN = 11
+# pos  0  1  2  3  4  5  6  7  8  9 10
+#    00 63 00 3c 04 00 00 00 00 00 02
+#     |  |  |  |  |  |  |  |  |  |  checksum
+#     |  |  |  |  |  |  |  |  |  ??
+#     |  |  |  |  |  |  |  |  ??
+#     |  |  |  |  |  |  |  ??
+#     |  |  |  |  |  |  ??
+#     |  |  |  |  |  ???
+#     |  |  |  |  ????
+#     |  |  |  ic
+#     |  |  num pixels (16 bit, low byte)
+#     |  num pixels (16 bit, high byte)
+#     msg head
 
 MSG_ORIGINAL_POWER_STATE = "original_power_state"
 MSG_ORIGINAL_STATE = "original_state"
@@ -44,14 +61,16 @@ MSG_STATE = "state"
 
 MSG_ADDRESSABLE_STATE = "addressable_state"
 
+MSG_IC_CONFIG = "ic_config"
+
 MSG_FIRST_BYTE = {
     0xF0: MSG_POWER_STATE,
-    0x00: MSG_POWER_STATE,
     0x0F: MSG_POWER_STATE,
     0x78: MSG_ORIGINAL_POWER_STATE,
     0x66: MSG_ORIGINAL_STATE,
     0x81: MSG_STATE,
     0xB0: MSG_ADDRESSABLE_STATE,
+    0x00: MSG_IC_CONFIG,
 }
 MSG_LENGTHS = {
     MSG_POWER_STATE: LEDENET_POWER_RESPONSE_LEN,
@@ -59,6 +78,7 @@ MSG_LENGTHS = {
     MSG_ORIGINAL_STATE: LEDENET_ORIGINAL_STATE_RESPONSE_LEN,
     MSG_STATE: LEDENET_STATE_RESPONSE_LEN,
     MSG_ADDRESSABLE_STATE: LEDENET_ADDRESSABLE_STATE_RESPONSE_LEN,
+    MSG_IC_CONFIG: LEDENET_IC_STATE_RESPONSE_LEN,
 }
 
 
@@ -138,7 +158,7 @@ class ProtocolBase:
     power_state_response_length = MSG_LENGTHS[MSG_POWER_STATE]
 
     def __init__(self) -> None:
-        self._counter = 0
+        self._counter = -1
         super().__init__()
 
     @property
@@ -146,6 +166,21 @@ class ProtocolBase:
         """If True the device must be turned on before setting level/patterns/modes."""
         return True
 
+    @property
+    def power_push_updates(self) -> bool:
+        """If True the protocol pushes power state updates when controlled via ir/rf/app."""
+        return False
+
+    @property
+    def state_push_updates(self) -> bool:
+        """If True the protocol pushes state updates when controlled via ir/rf/app."""
+        return False
+
+    @property
+    def zones(self) -> bool:
+        """If the protocol supports zones."""
+        return False
+
     def _increment_counter(self) -> int:
         """Increment the counter byte."""
         self._counter += 1
@@ -153,14 +188,14 @@ class ProtocolBase:
             self._counter = 0
         return self._counter
 
-    def is_start_of_addressable_response(self, data: bytes) -> bool:
-        """Check if a message is the start of an addressable state response."""
-        return False
-
     def is_valid_addressable_response(self, data: bytes) -> bool:
         """Check if a message is a valid addressable state response."""
         return False
 
+    def is_valid_ic_response(self, data: bytes) -> bool:
+        """Check if a message is a valid ic state response."""
+        return False
+
     def expected_response_length(self, data: bytes) -> int:
         """Return the number of bytes expected in the response.
 
@@ -180,10 +215,6 @@ class ProtocolBase:
     def is_valid_state_response(self, raw_state: bytes) -> bool:
         """Check if a state response is valid."""
 
-    @abstractmethod
-    def is_start_of_state_response(self, data: bytes) -> bool:
-        """Check if a message is the start of a state response."""
-
     def is_checksum_correct(self, msg: bytes) -> bool:
         """Check a checksum of a message."""
         expected_sum = sum(msg[0:-1]) & 0xFF
@@ -198,10 +229,6 @@ class ProtocolBase:
     def is_valid_power_state_response(self, msg: bytes) -> bool:
         """Check if a power state response is valid."""
 
-    @abstractmethod
-    def is_start_of_power_state_response(self, data: bytes) -> bool:
-        """Check if a message is the start of a power response."""
-
     @property
     def on_byte(self) -> int:
         """The on byte."""
@@ -222,7 +249,15 @@ class ProtocolBase:
         """The bytes to send for a state change request."""
 
     @abstractmethod
-    def construct_music_mode(self, sensitivity: int) -> bytearray:
+    def construct_music_mode(
+        self,
+        sensitivity: int,
+        brightness: int,
+        mode: Optional[int],
+        effect: Optional[int],
+        foreground_colors: Optional[Tuple[int, int, int]] = None,
+        background_colors: Optional[Tuple[int, int, int]] = None,
+    ) -> List[bytearray]:
         """The bytes to send to set music mode."""
 
     @abstractmethod
@@ -318,14 +353,6 @@ class ProtocolLEDENETOriginal(ProtocolBase):
             and raw_state[1] == 0x01
         )
 
-    def is_start_of_state_response(self, data: bytes) -> bool:
-        """Check if a message is the start of a state response."""
-        return data[0] == 0x66
-
-    def is_start_of_power_state_response(self, data: bytes) -> bool:
-        """Check if a message is the start of a state response."""
-        return data[0] == 0x78
-
     def construct_state_query(self) -> bytearray:
         """The bytes to send for a query request."""
         return self.construct_message(bytearray([0xEF, 0x01, 0x77]))
@@ -387,26 +414,22 @@ class ProtocolLEDENET8Byte(ProtocolBase):
         """Check if a power state response is valid."""
         if (
             len(msg) != self.power_state_response_length
-            or not self.is_start_of_power_state_response(msg)
+            or not self._is_start_of_power_state_response(msg)
             or msg[1] != 0x71
             or msg[2] not in (self.on_byte, self.off_byte)
         ):
             return False
         return self.is_checksum_correct(msg)
 
-    def is_start_of_power_state_response(self, data: bytes) -> bool:
+    def _is_start_of_power_state_response(self, data: bytes) -> bool:
         """Check if a message is the start of a state response."""
         return len(data) >= 1 and MSG_FIRST_BYTE[data[0]] == MSG_POWER_STATE
 
-    def is_start_of_state_response(self, data: bytes) -> bool:
-        """Check if a message is the start of a state response."""
-        return data[0] == 0x81
-
     def is_valid_state_response(self, raw_state: bytes) -> bool:
         """Check if a state response is valid."""
         if len(raw_state) != self.state_response_length:
             return False
-        if not self.is_start_of_state_response(raw_state):
+        if not raw_state[0] == 0x81:
             return False
         return self.is_checksum_correct(raw_state)
 
@@ -485,8 +508,16 @@ class ProtocolLEDENET8Byte(ProtocolBase):
         """Convert raw_state to a namedtuple."""
         return LEDENETRawState(*raw_state)
 
-    def construct_music_mode(self, sensitivity: int) -> bytearray:
-        """The bytes to send for a level change request.
+    def construct_music_mode(
+        self,
+        sensitivity: int,
+        brightness: int,
+        mode: Optional[int],
+        effect: Optional[int],
+        foreground_colors: Optional[Tuple[int, int, int]] = None,
+        background_colors: Optional[Tuple[int, int, int]] = None,
+    ) -> List[bytearray]:
+        """The bytes to send for music mode.
 
         Known messages
         73 01 4d 0f d0
@@ -518,31 +549,57 @@ class ProtocolLEDENET8Byte(ProtocolBase):
         37 02 00 39  Jump
         37 03 00 3a  Strobe
         """
-        return self.construct_message(bytearray([0x73, 0x01, sensitivity, 0x0F]))
-
-    def is_start_of_addressable_response(self, data: bytes) -> bool:
-        """Check if a message is the start of an addressable state response."""
-        return data.startswith(bytearray(self.ADDRESSABLE_HEADER))
+        # Valid modes
+        # 0x00 - Fade In
+        # 0x01 - Gradual
+        # 0x02 - Jump
+        # 0x03 - Strobe
+        return [
+            self.construct_message(bytearray([0x73, 0x01, sensitivity, 0x0F])),
+            self.construct_message(bytearray([0x37, mode or 0x00, 0x00])),
+        ]
 
     def is_valid_addressable_response(self, data: bytes) -> bool:
         """Check if a message is a valid addressable state response."""
         if len(data) != self.addressable_response_length:
             return False
-        if not self.is_start_of_addressable_response(data):
+        if not data.startswith(bytearray(self.ADDRESSABLE_HEADER)):
             return False
         return self.is_checksum_correct(data)
 
 
-class ProtocolLEDENET8ByteDimmableEffects(ProtocolLEDENET8Byte):
+class ProtocolLEDENET8ByteAutoOn(ProtocolLEDENET8Byte):
+    """Protocol that uses 8 bytes, and turns on by changing levels or effects."""
+
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
+    @property
+    def name(self) -> str:
+        """The name of the protocol."""
+        return PROTOCOL_LEDENET_8BYTE_AUTO_ON
+
+
+# This protocol also supports Candle mode but its not currently implemented here
+class ProtocolLEDENET8ByteDimmableEffects(ProtocolLEDENET8ByteAutoOn):
+    """Protocol that uses 8 bytes, and supports dimmable effects and auto on by changing levels or effects."""
+
     @property
     def dimmable_effects(self) -> bool:
         """Protocol supports dimmable effects."""
         return True
 
     @property
-    def requires_turn_on(self) -> bool:
-        """If True the device must be turned on before setting level/patterns/modes."""
-        return False
+    def power_push_updates(self) -> bool:
+        """If True the protocol pushes power state updates when controlled via ir/rf/app."""
+        return True
+
+    @property
+    def state_push_updates(self) -> bool:
+        """If True the protocol pushes state updates when controlled via ir/rf/app."""
+        return True
 
     @property
     def name(self) -> str:
@@ -605,7 +662,22 @@ class ProtocolLEDENET9Byte(ProtocolLEDENET8Byte):
         )
 
 
-class ProtocolLEDENET9ByteDimmableEffects(ProtocolLEDENET9Byte):
+class ProtocolLEDENET9ByteAutoOn(ProtocolLEDENET9Byte):
+    """Protocol that uses 9 bytes, and turns on by changing levels or effects."""
+
+    @property
+    def requires_turn_on(self) -> bool:
+        """If True the device must be turned on before setting level/patterns/modes."""
+        return False
+
+    @property
+    def name(self) -> str:
+        """The name of the protocol."""
+        return PROTOCOL_LEDENET_9BYTE_AUTO_ON
+
+
+# This protocol also supports Candle mode but its not currently implemented here
+class ProtocolLEDENET9ByteDimmableEffects(ProtocolLEDENET9ByteAutoOn):
     """The newer LEDENET protocol with checksums that uses 9 bytes to set state."""
 
     @property
@@ -613,16 +685,21 @@ class ProtocolLEDENET9ByteDimmableEffects(ProtocolLEDENET9Byte):
         """Protocol supports dimmable effects."""
         return True
 
+    @property
+    def power_push_updates(self) -> bool:
+        """If True the protocol pushes power state updates when controlled via ir/rf/app."""
+        return True
+
+    @property
+    def state_push_updates(self) -> bool:
+        """If True the protocol pushes state updates when controlled via ir/rf/app."""
+        return True
+
     @property
     def name(self) -> str:
         """The name of the protocol."""
         return PROTOCOL_LEDENET_9BYTE_DIMMABLE_EFFECTS
 
-    @property
-    def requires_turn_on(self) -> bool:
-        """If True the device must be turned on before setting level/patterns/modes."""
-        return False
-
     def construct_preset_pattern(
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
@@ -631,12 +708,22 @@ class ProtocolLEDENET9ByteDimmableEffects(ProtocolLEDENET9Byte):
         return self.construct_message(bytearray([0x38, pattern, delay, brightness]))
 
 
-class ProtocolLEDENETAddressableA1(ProtocolLEDENET9Byte):
+class ProtocolLEDENETAddressableBase(ProtocolLEDENET9Byte):
+    def construct_request_strip_setting(self) -> bytearray:
+        return self.construct_message(bytearray([0x63, 0x12, 0x21]))
+
+
+class ProtocolLEDENETAddressableA1(ProtocolLEDENETAddressableBase):
     @property
     def name(self) -> str:
         """The name of the protocol."""
         return PROTOCOL_LEDENET_ADDRESSABLE_A1
 
+    @property
+    def power_push_updates(self) -> bool:
+        """If True the protocol pushes power state updates when controlled via ir/rf/app."""
+        return True
+
     @property
     def dimmable_effects(self) -> bool:
         """Protocol supports dimmable effects."""
@@ -657,12 +744,22 @@ class ProtocolLEDENETAddressableA1(ProtocolLEDENET9Byte):
         )
 
 
-class ProtocolLEDENETAddressableA2(ProtocolLEDENET9Byte):
+class ProtocolLEDENETAddressableA2(ProtocolLEDENETAddressableBase):
+
+    # ic response
+    # 0x96 0x63 0x00 0x32 0x00 0x01 0x01 0x04 0x32 0x01 0x64 (11)
+
     @property
     def name(self) -> str:
         """The name of the protocol."""
         return PROTOCOL_LEDENET_ADDRESSABLE_A2
 
+    @property
+    def power_push_updates(self) -> bool:
+        """If True the protocol pushes power state updates when controlled via ir/rf/app."""
+        # This is likely due to buggy firmware
+        return False
+
     @property
     def dimmable_effects(self) -> bool:
         """Protocol supports dimmable effects."""
@@ -713,8 +810,16 @@ class ProtocolLEDENETAddressableA2(ProtocolLEDENET9Byte):
             )
         )
 
-    def construct_music_mode(self, sensitivity: int) -> bytearray:
-        """The bytes to send for a level change request.
+    def construct_music_mode(
+        self,
+        sensitivity: int,
+        brightness: int,
+        mode: Optional[int],
+        effect: Optional[int],
+        foreground_colors: Optional[Tuple[int, int, int]] = None,
+        background_colors: Optional[Tuple[int, int, int]] = None,
+    ) -> List[bytearray]:
+        """The bytes to send for music mode.
 
         Known messages
         73 01 27 01 00 00 00 00 ff ff 64 64 62 - lowest brightness music
@@ -751,30 +856,51 @@ class ProtocolLEDENETAddressableA2(ProtocolLEDENET9Byte):
                                          ^brightness <-- led strip mode color
 
         """
-        red = 0xFF
-        green = 0x00
-        blue = 0x00
-
-        return self.construct_message(
-            bytearray(
-                [
-                    0x73,
-                    0x01,
-                    red,
-                    green,
-                    blue,
-                    red,
-                    green,
-                    blue,
-                    sensitivity,
-                    0x64,
-                    0x64,
-                ]
+        if foreground_colors is None:
+            foreground_colors = (0xFF, 0x00, 0x00)
+        if background_colors is None:
+            background_colors = (0x00, 0x00, 0x00)
+        return [
+            self.construct_message(
+                bytearray(
+                    [
+                        0x73,
+                        0x01,
+                        mode or 0x26,  # strip mode 0x26, light bar mode 0x27
+                        effect or 0x01,
+                        *foreground_colors,
+                        *background_colors,
+                        sensitivity,
+                        brightness,
+                    ]
+                )
             )
-        )
+        ]
 
 
-class ProtocolLEDENETAddressableA3(ProtocolLEDENET9Byte):
+class ProtocolLEDENETAddressableA3(ProtocolLEDENETAddressableA2):
+
+    # ic response
+    # 0x00 0x63 0x00 0x32 0x00 0x01 0x04 0x03 0x32 0x01 0xD0 (11)
+    # b0 b1 b2 b3 00 01 01 37 00 0b 00 63 00 32 00 01 04 03 32 01 d0 aa
+    @property
+    def power_push_updates(self) -> bool:
+        """If True the protocol pushes power state updates when controlled via ir/rf/app."""
+        return True
+
+    @property
+    def zones(self) -> bool:
+        """If the protocol supports zones."""
+        return True
+
+    def is_valid_ic_response(self, data: bytes) -> bool:
+        """Check if a message is a valid ic state response."""
+        if len(data) != LEDENET_IC_STATE_RESPONSE_LEN:
+            return False
+        if not data.startswith(bytearray([0x00, 0x63])):
+            return False
+        return self.is_checksum_correct(data)
+
     @property
     def name(self) -> str:
         """The name of the protocol."""
@@ -794,12 +920,11 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENET9Byte):
         self, pattern: int, speed: int, brightness: int
     ) -> bytearray:
         """The bytes to send for a preset pattern."""
-        counter_byte = self._increment_counter()
         return self.construct_message(
             bytearray(
                 [
                     *self.ADDRESSABLE_HEADER,
-                    counter_byte,
+                    self._increment_counter(),
                     0x00,
                     0x05,
                     0x42,
@@ -811,8 +936,20 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENET9Byte):
             )
         )
 
-    def construct_music_mode(self, sensitivity: int) -> bytearray:
-        """The bytes to send for a level change request.
+    # To query music mode
+    # Send     -> b0 b1 b2 b3 00 01 01 1c 00 03 72 00 72 cb
+    # Responds <- b0 b1 b2 b3 00 01 01 1c 00 0d 72 01 26 01 00 00 00 00 00 00 64 64 62 b5
+
+    def construct_music_mode(
+        self,
+        sensitivity: int,
+        brightness: int,
+        mode: Optional[int],
+        effect: Optional[int],
+        foreground_colors: Optional[Tuple[int, int, int]] = None,
+        background_colors: Optional[Tuple[int, int, int]] = None,
+    ) -> List[bytearray]:
+        """The bytes to send for music mode.
 
         Known messages
         b0 b1 b2 b3 00 01 01 1f 00 0d 73 01 27 01 ff 00 00 ff 00 00 64 64 62 b8 - Music mode
@@ -830,33 +967,30 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENET9Byte):
         b0 b1 b2 b3 00 01 01 5f 00 0d 73 01 27 01 ff a6 00 ff 00 00 64 64 08 44 - Music mode (various sensitivity)
         b0 b1 b2 b3 00 01 01 69 00 0d 73 01 26 01 ff 00 00 ff 00 00 00 64 fd 38 - Music mode (various sensitivity)
         b0 b1 b2 b3 00 01 01 68 00 0d 73 01 26 01 ff 00 00 ff 00 00 64 64 61 ff - Music mode (various sensitivity)
-        """
-        counter_byte = self._increment_counter()
-        red = 0xFF
-        green = 0x00
-        blue = 0x00
-        inner_message = self.construct_message(
-            bytearray(
-                [
-                    0x73,
-                    0x01,
-                    red,
-                    green,
-                    blue,
-                    red,
-                    green,
-                    blue,
-                    sensitivity,
-                    0x64,
-                ]
-            )
-        )
 
-        return self.construct_message(
-            bytearray(
-                [*self.ADDRESSABLE_HEADER, counter_byte, 0x00, 0x0D, *inner_message]
-            )
+
+        b0 b1 b2 b3 00 01 01 08 00 0d 73 01 26 02 00 00 00 00 ff ff 64 60 5e 99 -- red lines
+        b0 b1 b2 b3 00 01 01 16 00 0d 73 01 26 02 00 00 00 00 ff ff 64 64 62 af -- red lines
+        b0 b1 b2 b3 00 01 01 17 00 0d 73 01 26 01 00 00 00 00 ff ff 64 64 61 ae -- rainbow lines
+                                                                       ^^
+                                                                       Likely brightness from 0-100 (0x64)
+        """
+        inner_message = super().construct_music_mode(
+            sensitivity, brightness, mode, effect, foreground_colors, background_colors
         )
+        return [
+            self.construct_message(
+                bytearray(
+                    [
+                        *self.ADDRESSABLE_HEADER,
+                        self._increment_counter(),
+                        0x00,
+                        0x0D,
+                        *inner_message[0],
+                    ]
+                )
+            )
+        ]
 
     def construct_levels_change(
         self,
@@ -909,7 +1043,6 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENET9Byte):
         Set Red
         b0b1b2b30001010d0034a0000600010000ff0000ff0002ff00000000ff00030000ff0000ff0004ff00000000ff00050000ff0000ff0006ff00000000ffaf67
         """
-        counter_byte = self._increment_counter()
         preset_number = 0x01  # aka fixed color
         inner_message = self.construct_message(
             bytearray(
@@ -932,7 +1065,79 @@ class ProtocolLEDENETAddressableA3(ProtocolLEDENET9Byte):
 
         return self.construct_message(
             bytearray(
-                [*self.ADDRESSABLE_HEADER, counter_byte, 0x00, 0x0D, *inner_message]
+                [
+                    *self.ADDRESSABLE_HEADER,
+                    self._increment_counter(),
+                    0x00,
+                    0x0D,
+                    *inner_message,
+                ]
+            )
+        )
+
+    def construct_zone_change(
+        self,
+        points: int,  # the number of points on the strip
+        rgb_list: List[Tuple[int, int, int]],
+        speed: int,
+        effect: MultiColorEffects,
+    ) -> bytearray:
+        """The bytes to send for multiple zones.
+
+        Blue/Green - Static
+        590063ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff00000000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff001e04640024
+
+        Red/Blue - Jump
+        5900630000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff00ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff00001e01640021
+
+        White/Green - Static
+        590063ffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff00ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff00001e01640003
+            11111 22222 33333 44444 55555 66666 77777 88888 99999 00000 11111 22222 33333 44444 55555
+
+        White - Static
+        590063ffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff001e016400e5
+
+        White - Running Water - Full speed
+        590063ffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff001e026400e6
+
+        White - Running Water - 50% speed
+        590063ffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffff001e023200b4
+
+        Red - Blue - Gradient
+        590063ff0000f60008ed0011e4001adb0023d3002bca0034c1003db80046af004fa700579e00609500698c007283007b7b008372008c69009560009e5700a74f00af4600b83d00c13400ca2b00d32300db1a00e41100ed0800f60000ff001e01640005
+
+        Red - Brething
+        590063ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000ff0000001e05640025
+        """
+        sent_zones = len(rgb_list)
+        pixel_bits = 9 + (points * 3)
+        pixels = bytearray([pixel_bits >> 8, pixel_bits & 0xFF])
+        msg = bytearray([0x59])
+        msg.extend(pixels)
+        zone_size = points // sent_zones
+        remaining = points
+        for rgb in rgb_list:
+            for _ in range(zone_size):
+                r, g, b = rgb
+                msg.extend(bytearray([r, g, b]))
+                remaining -= 1
+        while remaining:
+            remaining -= 1
+            r, g, b = rgb_list[-1]
+            msg.extend(bytearray([r, g, b]))
+        msg.extend(bytearray([0x00, 0x1E]))
+        msg.extend(bytearray([effect.value, speed]))
+        msg.append(0x00)
+        inner_message = self.construct_message(msg)
+
+        return self.construct_message(
+            bytearray(
+                [
+                    *self.ADDRESSABLE_HEADER,
+                    self._increment_counter(),
+                    *pixels,
+                    *inner_message,
+                ]
             )
         )
 
@@ -951,6 +1156,16 @@ class ProtocolLEDENETCCT(ProtocolLEDENET9Byte):
         """Protocol supports dimmable effects."""
         return False
 
+    @property
+    def power_push_updates(self) -> bool:
+        """If True the protocol pushes power state updates when controlled via ir/rf/app."""
+        return True
+
+    @property
+    def state_push_updates(self) -> bool:
+        """If True the protocol pushes state updates when controlled via ir/rf/app."""
+        return True
+
     @property
     def requires_turn_on(self) -> bool:
         """If True the device must be turned on before setting level/patterns/modes."""
@@ -972,7 +1187,6 @@ class ProtocolLEDENETCCT(ProtocolLEDENET9Byte):
         b0 b1 b2 b3 00 01 01 72 00 09 35 b1 64 64 00 00 00 03 b1 a5 - 100% cool
         b0 b1 b2 b3 00 01 01 9f 00 09 35 b1 64 32 00 00 00 03 7f 6e - 100% cool - dim 50%
         """
-        counter_byte = self._increment_counter()
         scaled_temp, brightness = white_levels_to_scaled_color_temp(
             warm_white, cool_white
         )
@@ -995,6 +1209,12 @@ class ProtocolLEDENETCCT(ProtocolLEDENET9Byte):
 
         return self.construct_message(
             bytearray(
-                [*self.ADDRESSABLE_HEADER, counter_byte, 0x00, 0x09, *inner_message]
+                [
+                    *self.ADDRESSABLE_HEADER,
+                    self._increment_counter(),
+                    0x00,
+                    0x09,
+                    *inner_message,
+                ]
             )
         )
