@@ -5,7 +5,21 @@ import select
 import socket
 import sys
 import time
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Dict, List, Optional, Tuple, Union, cast
+
+from .const import (
+    ATTR_FIRMWARE_DATE,
+    ATTR_ID,
+    ATTR_IPADDR,
+    ATTR_MODEL,
+    ATTR_MODEL_DESCRIPTION,
+    ATTR_MODEL_INFO,
+    ATTR_MODEL_NUM,
+    ATTR_REMOTE_ACCESS_ENABLED,
+    ATTR_REMOTE_ACCESS_HOST,
+    ATTR_REMOTE_ACCESS_PORT,
+    ATTR_VERSION_NUM,
+)
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict  # pylint: disable=no-name-in-module
@@ -28,6 +42,18 @@ class FluxLEDDiscovery(TypedDict):
     firmware_date: Optional[date]
     model_info: Optional[str]  # contains if IR (and maybe BL) if the device supports IR
     model_description: Optional[str]
+    remote_access_enabled: Optional[bool]
+    remote_access_host: Optional[str]  # the remote access host
+    remote_access_port: Optional[int]  # the remote access port
+
+
+def create_udp_socket() -> socket.socket:
+    """Create a udp socket used for communicating with the device."""
+    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+    sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
+    sock.bind(("", 0))
+    sock.setblocking(False)
+    return sock
 
 
 def merge_discoveries(target: FluxLEDDiscovery, source: FluxLEDDiscovery) -> None:
@@ -48,9 +74,9 @@ def _process_discovery_message(data: FluxLEDDiscovery, decoded_data: str) -> Non
     ipaddr = data_split[0]
     data.update(
         {
-            "ipaddr": ipaddr,
-            "id": data_split[1],
-            "model": data_split[2],
+            ATTR_IPADDR: ipaddr,
+            ATTR_ID: data_split[1],
+            ATTR_MODEL: data_split[2],
         }
     )
 
@@ -65,17 +91,19 @@ def _process_version_message(data: FluxLEDDiscovery, decoded_data: str) -> None:
     if len(data_split) < 2:
         return
     try:
-        data["model_num"] = int(data_split[0], 16)
-        data["version_num"] = int(data_split[1], 16)
+        data[ATTR_MODEL_NUM] = int(data_split[0], 16)
+        data[ATTR_VERSION_NUM] = int(data_split[1], 16)
     except ValueError:
         return
-    assert data["model_num"] is not None
-    data["model_description"] = get_model_description(data["model_num"])
+    assert data[ATTR_MODEL_NUM] is not None
+    data[ATTR_MODEL_DESCRIPTION] = get_model_description(
+        cast(int, data[ATTR_MODEL_NUM])
+    )
     if len(data_split) < 3:
         return
     firmware_date = data_split[2]
     try:
-        data["firmware_date"] = date(
+        data[ATTR_FIRMWARE_DATE] = date(
             int(firmware_date[:4]),
             int(firmware_date[4:6]),
             int(firmware_date[6:8]),
@@ -84,7 +112,29 @@ def _process_version_message(data: FluxLEDDiscovery, decoded_data: str) -> None:
         return
     if len(data_split) < 4:
         return
-    data["model_info"] = data_split[3]
+    data[ATTR_MODEL_INFO] = data_split[3]
+
+
+def _process_remote_access_message(data: FluxLEDDiscovery, decoded_data: str) -> None:
+    """Process response from b'AT+SOCKB\r'
+
+    b'+ok=TCP,8816,ra8816us02.magichue.net\r'
+    """
+    data_split = decoded_data.replace("\r", "").split(",")
+    if len(data_split) < 3:
+        if not data.get(ATTR_REMOTE_ACCESS_ENABLED):
+            data[ATTR_REMOTE_ACCESS_ENABLED] = False
+        return
+    try:
+        data.update(
+            {
+                ATTR_REMOTE_ACCESS_ENABLED: True,
+                ATTR_REMOTE_ACCESS_PORT: int(data_split[1]),
+                ATTR_REMOTE_ACCESS_HOST: data_split[2],
+            }
+        )
+    except ValueError:
+        return
 
 
 class BulbScanner:
@@ -94,6 +144,10 @@ class BulbScanner:
     RESPONSE_SIZE = 64
     DISCOVER_MESSAGE = b"HF-A11ASSISTHREAD"
     VERSION_MESSAGE = b"AT+LVER\r"
+    REMOTE_ACCESS_MESSAGE = b"AT+SOCKB\r"
+    DISABLE_REMOTE_ACCESS_MESSAGE = b"AT+SOCKB=NONE\r"
+    REBOOT_MESSAGE = b"AT+Z\r"
+    ALL_MESSAGES = {DISCOVER_MESSAGE, VERSION_MESSAGE, REMOTE_ACCESS_MESSAGE}
     BROADCAST_ADDRESS = "<broadcast>"
 
     def __init__(self) -> None:
@@ -114,11 +168,7 @@ class BulbScanner:
         return self.found_bulbs
 
     def _create_socket(self) -> socket.socket:
-        sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-        sock.setsockopt(socket.SOL_SOCKET, socket.SO_BROADCAST, 1)
-        sock.bind(("", 0))
-        sock.setblocking(False)
-        return sock
+        return create_udp_socket()
 
     def _destination_from_address(self, address: Optional[str]) -> Tuple[str, int]:
         if address is None:
@@ -138,13 +188,17 @@ class BulbScanner:
         """
         if data is None:
             return False
-        if data in (self.DISCOVER_MESSAGE, self.VERSION_MESSAGE):
+        if data in self.ALL_MESSAGES:
             return False
         decoded_data = data.decode("ascii")
         self._process_data(from_address, decoded_data, response_list)
         if address is None or address not in response_list:
             return False
-        return response_list[address]["model_num"] is not None
+        response = response_list[address]
+        return (
+            response[ATTR_MODEL_NUM] is not None
+            and response[ATTR_REMOTE_ACCESS_ENABLED] is not None
+        )
 
     def _process_data(
         self,
@@ -165,22 +219,70 @@ class BulbScanner:
                 firmware_date=None,
                 model_info=None,
                 model_description=None,
+                remote_access_enabled=None,
+                remote_access_host=None,
+                remote_access_port=None,
             ),
         )
+        if (
+            decoded_data.startswith("+ok=T")
+            or decoded_data == "+ok="
+            or decoded_data == "+ok=\r"
+        ):
+            _process_remote_access_message(data, decoded_data)
         if decoded_data.startswith("+ok="):
             _process_version_message(data, decoded_data)
         elif "," in decoded_data:
             _process_discovery_message(data, decoded_data)
 
+    def send_start_message(
+        self,
+        sender: Union[socket.socket, asyncio.DatagramTransport],
+        destination: Tuple[str, int],
+    ) -> None:
+        self._send_message(sender, destination, self.DISCOVER_MESSAGE)
+
+    def send_enable_remote_access_message(
+        self,
+        sender: Union[socket.socket, asyncio.DatagramTransport],
+        destination: Tuple[str, int],
+        remote_access_host: str,
+        remote_access_port: int,
+    ) -> None:
+        enable_message = f"AT+SOCKB=TCP,{remote_access_port},{remote_access_host}\r"
+        self._send_message(sender, destination, enable_message.encode())
+
+    def send_disable_remote_access_message(
+        self,
+        sender: Union[socket.socket, asyncio.DatagramTransport],
+        destination: Tuple[str, int],
+    ) -> None:
+        self._send_message(sender, destination, self.DISABLE_REMOTE_ACCESS_MESSAGE)
+
+    def send_reboot_message(
+        self,
+        sender: Union[socket.socket, asyncio.DatagramTransport],
+        destination: Tuple[str, int],
+    ) -> None:
+        self._send_message(sender, destination, self.REBOOT_MESSAGE)
+
+    def _send_message(
+        self,
+        sender: Union[socket.socket, asyncio.DatagramTransport],
+        destination: Tuple[str, int],
+        message: bytes,
+    ) -> None:
+        _LOGGER.debug("udp: %s => %s", destination, message)
+        sender.sendto(message, destination)
+
     def send_discovery_messages(
         self,
         sender: Union[socket.socket, asyncio.DatagramTransport],
         destination: Tuple[str, int],
     ) -> None:
-        _LOGGER.debug("discover: %s => %s", destination, self.DISCOVER_MESSAGE)
-        sender.sendto(self.DISCOVER_MESSAGE, destination)
-        _LOGGER.debug("discover: %s => %s", destination, self.VERSION_MESSAGE)
-        sender.sendto(self.VERSION_MESSAGE, destination)
+        self.send_start_message(sender, destination)
+        self._send_message(sender, destination, self.VERSION_MESSAGE)
+        self._send_message(sender, destination, self.REMOTE_ACCESS_MESSAGE)
 
     def scan(
         self, timeout: int = 10, address: Optional[str] = None
